[modular tests] Use fuchsia-pkg URLs.

Use fuchsia-pkg URLs in integration test configurations. This
requires https://fuchsia-review.googlesource.com/c/garnet/+/232893
to write the command line as array instead of as string.

Also change all internally used component references to
fuchsia-pkg URLs.

TESTED=run_modular_tests.sh

Change-Id: Id39f5d74edc2437fd305dd673c1a48e89ed085d7
diff --git a/tests/chain/defs.h b/tests/chain/defs.h
index 72432ae..c316a2e 100644
--- a/tests/chain/defs.h
+++ b/tests/chain/defs.h
@@ -8,8 +8,10 @@
 namespace {
 
 // Package URLs of the test components used here.
-constexpr char kModuleUrl[] = "chain_test_module";
-constexpr char kChildModuleUrl[] = "chain_test_child_module";
+constexpr char kModuleUrl[] =
+    "fuchsia-pkg://fuchsia.com/chain_test_module#meta/chain_test_module.cmx";
+constexpr char kChildModuleUrl[] =
+    "fuchsia-pkg://fuchsia.com/chain_test_child_module#meta/chain_test_child_module.cmx";
 
 }  // namespace
 
diff --git a/tests/clipboard/defs.h b/tests/clipboard/defs.h
index c4f3d31..a073220 100644
--- a/tests/clipboard/defs.h
+++ b/tests/clipboard/defs.h
@@ -8,7 +8,8 @@
 namespace {
 
 // The url of the clipboard agent under test.
-constexpr char kClipboardAgentUrl[] = "clipboard_agent";
+constexpr char kClipboardAgentUrl[] =
+    "fuchsia-pkg://fuchsia.com/clipboard_agent#meta/clipboard_agent.cmx";
 
 }  // namespace
 
diff --git a/tests/common/defs.h b/tests/common/defs.h
index d599c65..12ec49d 100644
--- a/tests/common/defs.h
+++ b/tests/common/defs.h
@@ -7,13 +7,15 @@
 
 namespace {
 
-constexpr char kCommonNullModule[] = "common_null_module";
+constexpr char kCommonNullModule[] =
+    "fuchsia-pkg://fuchsia.com/common_null_module#meta/common_null_module.cmx";
 constexpr char kCommonNullAction[] = "com.google.fuchsia.common.null";
 
 constexpr char kCommonNullModuleStarted[] = "common_null_module_started";
 constexpr char kCommonNullModuleStopped[] = "common_null_module_stopped";
 
-constexpr char kCommonActiveModule[] = "common_active_module";
+constexpr char kCommonActiveModule[] =
+    "fuchsia-pkg://fuchsia.com/common_active_module#meta/common_active_module.cmx";
 constexpr char kCommonActiveAction[] = "com.google.fuchsia.common.active";
 
 constexpr char kCommonActiveModuleStarted[] = "common_active_module_started";
diff --git a/tests/component_context/defs.h b/tests/component_context/defs.h
index c1287a7..f2f11c5 100644
--- a/tests/component_context/defs.h
+++ b/tests/component_context/defs.h
@@ -8,9 +8,12 @@
 namespace {
 
 // Package URLs of the test components used here.
-constexpr char kOneAgentUrl[] = "component_context_test_one_agent";
-constexpr char kUnstoppableAgent[] = "component_context_test_unstoppable_agent";
-constexpr char kTwoAgentUrl[] = "component_context_test_two_agent";
+constexpr char kOneAgentUrl[] =
+    "fuchsia-pkg://fuchsia.com/component_context_test_one_agent#meta/component_context_test_one_agent.cmx";
+constexpr char kUnstoppableAgent[] =
+    "fuchsia-pkg://fuchsia.com/component_context_test_unstoppable_agent#meta/component_context_test_unstoppable_agent.cmx";
+constexpr char kTwoAgentUrl[] =
+    "fuchsia-pkg://fuchsia.com/component_context_test_two_agent#meta/component_context_test_two_agent.cmx";
 
 constexpr int kTotalSimultaneousTests = 2;
 
diff --git a/tests/embed_shell/defs.h b/tests/embed_shell/defs.h
index 4dc6bef..3d25f90 100644
--- a/tests/embed_shell/defs.h
+++ b/tests/embed_shell/defs.h
@@ -10,7 +10,8 @@
 constexpr char kChildModuleName[] = "child";
 
 // Package URLs of the test components used here.
-constexpr char kChildModuleUrl[] = "embed_shell_test_child_module";
+constexpr char kChildModuleUrl[] =
+    "fuchsia-pkg://fuchsia.com/embed_shell_test_child_module#meta/embed_shell_test_child_module.cmx";
 
 constexpr char kChildModuleAction[] = "action";
 
diff --git a/tests/intents/defs.h b/tests/intents/defs.h
index bd07012..a527010 100644
--- a/tests/intents/defs.h
+++ b/tests/intents/defs.h
@@ -10,7 +10,9 @@
 constexpr char kChildModuleName[] = "child";
 
 // Package URLs of the test components used here.
-constexpr char kChildModuleUrl[] = "intent_test_child_module";
+constexpr char kChildModuleUrl[] =
+    "fuchsia-pkg://fuchsia.com/intent_test_child_module#meta/intent_test_child_module.cmx";
+
 // The action of the intent the parent module issues to the child module.
 constexpr char kChildModuleAction[] = "intent_test_child_module_action";
 
diff --git a/tests/link_context_entities/defs.h b/tests/link_context_entities/defs.h
index ccb7d9a..d7182a5 100644
--- a/tests/link_context_entities/defs.h
+++ b/tests/link_context_entities/defs.h
@@ -8,7 +8,8 @@
 namespace {
 
 // Package URLs of the test components used here.
-constexpr char kModuleUrl[] = "link_context_entities_test_module";
+constexpr char kModuleUrl[] =
+    "fuchsia-pkg://fuchsia.com/link_context_entities_test_module#meta/link_context_entities_test_module.cmx";
 constexpr char kModuleAction[] = "action";
 
 }  // namespace
diff --git a/tests/link_data/defs.h b/tests/link_data/defs.h
index ded6e5d..0aeadd2 100644
--- a/tests/link_data/defs.h
+++ b/tests/link_data/defs.h
@@ -8,15 +8,18 @@
 namespace {
 
 // Package URLs and actions of the test components used here.
-constexpr char kModule0Url[] = "link_data_test_module0";
+constexpr char kModule0Url[] =
+    "fuchsia-pkg://fuchsia.com/link_data_test_module0#meta/link_data_test_module0.cmx";
 constexpr char kModule0Action[] = "action";
 constexpr char kModule0Name[] = "module0";
 
-constexpr char kModule1Url[] = "link_data_test_module1";
+constexpr char kModule1Url[] =
+    "fuchsia-pkg://fuchsia.com/link_data_test_module1#meta/link_data_test_module1.cmx";
 constexpr char kModule1Action[] = "action";
 constexpr char kModule1Name[] = "module1";
 
-constexpr char kModule2Url[] = "link_data_test_module2";
+constexpr char kModule2Url[] =
+    "fuchsia-pkg://fuchsia.com/link_data_test_module2#meta/link_data_test_module2.cmx";
 constexpr char kModule2Action[] = "action";
 constexpr char kModule2Name[] = "module2";
 
diff --git a/tests/link_passing/defs.h b/tests/link_passing/defs.h
index b85489b..0370b31 100644
--- a/tests/link_passing/defs.h
+++ b/tests/link_passing/defs.h
@@ -8,10 +8,12 @@
 namespace {
 
 // Package URLs of the test components used here.
-constexpr char kModule2Url[] = "link_passing_test_module2";
+constexpr char kModule2Url[] =
+    "fuchsia-pkg://fuchsia.com/link_passing_test_module2#meta/link_passing_test_module2.cmx";
 constexpr char kModule2Action[] = "module2_action";
 
-constexpr char kModule3Url[] = "link_passing_test_module3";
+constexpr char kModule3Url[] =
+    "fuchsia-pkg://fuchsia.com/link_passing_test_module3#meta/link_passing_test_module3.cmx";
 constexpr char kModule3Action[] = "module3_action";
 
 }  // namespace
diff --git a/tests/modular_tests.json b/tests/modular_tests.json
index 0834088..0e65da8 100644
--- a/tests/modular_tests.json
+++ b/tests/modular_tests.json
@@ -2,73 +2,199 @@
   "tests": [
     {
       "name": "chain",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=chain_test_session_shell --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/chain_test_session_shell#meta/chain_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ]
     },
     {
       "name": "clipboard",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=dev_session_shell --session_shell_args=--root_module=clipboard_test_module --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/dev_session_shell#meta/dev_session_shell.cmx",
+        "--session_shell_args=--root_module=fuchsia-pkg://fuchsia.com/clipboard_test_module#meta/clipboard_test_module.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ]
     },
     {
       "name": "component_context",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=dev_session_shell --story_shell=dev_story_shell --session_shell_args=--root_module=component_context_test_module"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/dev_session_shell#meta/dev_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx",
+        "--session_shell_args=--root_module=fuchsia-pkg://fuchsia.com/component_context_test_module#meta/component_context_test_module.cmx"
+      ]
     },
     {
       "name": "embed_shell",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=dev_session_shell --story_shell=embed_shell_test_story_shell --session_shell_args=--root_module=embed_shell_test_parent_module"
+      "exec": [
+        "basemgr",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/dev_session_shell#meta/dev_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/embed_shell_test_story_shell#meta/embed_shell_test_story_shell.cmx",
+        "--session_shell_args=--root_module=fuchsia-pkg://fuchsia.com/embed_shell_test_parent_module#meta/embed_shell_test_parent_module.cmx"
+      ]
     },
     {
       "name": "last_focus_time",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=last_focus_time_test_session_shell --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/last_focus_time_test_session_shell#meta/last_focus_time_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ]
     },
     {
       "name": "link_context_entities",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=link_context_entities_test_session_shell --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/link_context_entities_test_session_shell#meta/link_context_entities_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ]
     },
     {
       "name": "link_data",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=link_data_test_session_shell --story_shell=dev_story_shell",
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/link_data_test_session_shell#meta/link_data_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ],
       "disabled": true
     },
     {
       "name": "link_passing",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=dev_session_shell --story_shell=dev_story_shell --session_shell_args=--root_module=link_passing_test_module1"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/dev_session_shell#meta/dev_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx",
+        "--session_shell_args=--root_module=fuchsia-pkg://fuchsia.com/link_passing_test_module1#meta/link_passing_test_module1.cmx"
+      ]
     },
     {
       "name": "parent_child",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=dev_session_shell --story_shell=dev_story_shell --session_shell_args=--root_module=parent_child_test_parent_module"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/dev_session_shell#meta/dev_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx",
+        "--session_shell_args=--root_module=fuchsia-pkg://fuchsia.com/parent_child_test_parent_module#meta/parent_child_test_parent_module.cmx"
+      ]
     },
     {
       "name": "queue_persistence",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=dev_session_shell --session_shell_args=--root_module=queue_persistence_test_module --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/dev_session_shell#meta/dev_session_shell.cmx",
+        "--session_shell_args=--root_module=fuchsia-pkg://fuchsia.com/queue_persistence_test_module#meta/queue_persistence_test_module.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ]
     },
     {
       "name": "story_shell",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=story_shell_test_session_shell --story_shell=story_shell_test_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/story_shell_test_session_shell#meta/story_shell_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/story_shell_test_story_shell#meta/story_shell_test_story_shell.cmx"
+      ]
     },
     {
       "name": "story_update",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=story_update_test_session_shell --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/story_update_test_session_shell#meta/story_update_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ]
     },
     {
       "name": "suggestion",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=suggestion_test_session_shell --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/suggestion_test_session_shell#meta/suggestion_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ]
     },
     {
       "name": "trigger",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=trigger_test_session_shell --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/trigger_test_session_shell#meta/trigger_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ]
     },
     {
       "name": "module_context",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=module_context_test_session_shell --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/module_context_test_session_shell#meta/module_context_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+      ]
     },
     {
       "name": "session_shell",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=session_shell_test_session_shell --story_shell=dev_story_shell"
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/session_shell_test_session_shell#meta/session_shell_test_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx"
+        ]
     },
     {
       "name": "intents",
-      "exec": "basemgr --test --account_provider=dev_token_manager --base_shell=dev_base_shell --session_shell=dev_session_shell --story_shell=dev_story_shell --session_shell_args=--root_module=intent_test_parent_module",
+      "exec": [
+        "fuchsia-pkg://fuchsia.com/basemgr#meta/basemgr.cmx",
+        "--test",
+        "--account_provider=fuchsia-pkg://fuchsia.com/dev_token_manager#meta/dev_token_manager.cmx",
+        "--base_shell=fuchsia-pkg://fuchsia.com/dev_base_shell#meta/dev_base_shell.cmx",
+        "--session_shell=fuchsia-pkg://fuchsia.com/dev_session_shell#meta/dev_session_shell.cmx",
+        "--story_shell=fuchsia-pkg://fuchsia.com/dev_story_shell#meta/dev_story_shell.cmx",
+        "--session_shell_args=--root_module=fuchsia-pkg://fuchsia.com/intent_test_parent_module#meta/intent_test_parent_module.cmx"
+      ],
       "disabled": true
     }
   ]
-}
\ No newline at end of file
+}
diff --git a/tests/module_context/module_context_test_session_shell.cc b/tests/module_context/module_context_test_session_shell.cc
index 205dd26..6a6d57a 100644
--- a/tests/module_context/module_context_test_session_shell.cc
+++ b/tests/module_context/module_context_test_session_shell.cc
@@ -344,7 +344,7 @@
   fuchsia::modular::Intent IntentWithParameterString(
       std::string parameter_string) {
     fuchsia::modular::Intent intent;
-    intent.handler = kModulePackageName;
+    intent.handler = kModuleUrl;
     intent.action = kIntentAction;
 
     fuchsia::modular::IntentParameter parameter;
diff --git a/tests/parent_child/defs.h b/tests/parent_child/defs.h
index 8a4068e..74e1152 100644
--- a/tests/parent_child/defs.h
+++ b/tests/parent_child/defs.h
@@ -10,9 +10,12 @@
 constexpr char kChildModuleName[] = "child";
 
 // Package URLs of the test components used here.
-constexpr char kChildModuleUrl1[] = "parent_child_test_child_module1";
-constexpr char kChildModuleUrl2[] = "parent_child_test_child_module2";
-constexpr char kChildModuleAction[] = "parent_child_test_child_module_action";
+constexpr char kChildModuleUrl1[] =
+    "fuchsia-pkg://fuchsia.com/parent_child_test_child_module1#meta/parent_child_test_child_module1.cmx";
+constexpr char kChildModuleUrl2[] =
+    "fuchsia-pkg://fuchsia.com/parent_child_test_child_module2#meta/parent_child_test_child_module2.cmx";
+constexpr char kChildModuleAction[] =
+    "fuchsia-pkg://fuchsia.com/parent_child_test_child_module_action#meta/parent_child_test_child_module_action.cmx";
 
 constexpr int kTimeoutMilliseconds = 5000;
 
diff --git a/tests/queue_persistence/defs.h b/tests/queue_persistence/defs.h
index 8f2b6a9..b9c4bb7 100644
--- a/tests/queue_persistence/defs.h
+++ b/tests/queue_persistence/defs.h
@@ -12,7 +12,8 @@
 constexpr int kTimeoutMilliseconds = 10000;
 
 // Package URLs of the test components used here.
-constexpr char kTestAgent[] = "queue_persistence_test_agent";
+constexpr char kTestAgent[] =
+    "fuchsia-pkg://fuchsia.com/queue_persistence_test_agent#meta/queue_persistence_test_agent.cmx";
 
 }  // namespace
 
diff --git a/tests/suggestion/defs.h b/tests/suggestion/defs.h
index 8240b31..03aa224 100644
--- a/tests/suggestion/defs.h
+++ b/tests/suggestion/defs.h
@@ -8,7 +8,9 @@
 namespace {
 
 // Package URLs of the test components used here.
-constexpr char kSuggestionTestModule[] = "suggestion_test_module";
+constexpr char kSuggestionTestModule[] =
+    "fuchsia-pkg://fuchsia.com/suggestion_test_module#meta/suggestion_test_module.cmx";
+
 constexpr char kSuggestionTestAction[] = "suggestion_test_action";
 
 constexpr char kSuggestionTestModuleDone[] = "suggestion_test_module_done";
diff --git a/tests/trigger/defs.h b/tests/trigger/defs.h
index bf990a7..11a4a37 100644
--- a/tests/trigger/defs.h
+++ b/tests/trigger/defs.h
@@ -12,8 +12,12 @@
 constexpr int kTimeoutMilliseconds = 10000;
 
 // Package URLs of the test components used here.
-constexpr char kTestAgent[] = "trigger_test_agent";
-const char kModuleUrl[] = "trigger_test_module";
+constexpr char kTestAgent[] =
+    "fuchsia-pkg://fuchsia.com/trigger_test_agent#meta/trigger_test_agent.cmx";
+
+const char kModuleUrl[] =
+    "fuchsia-pkg://fuchsia.com/trigger_test_module#meta/trigger_test_module.cmx";
+
 const char kModuleAction[] = "trigger_test_action";
 
 }  // namespace
diff --git a/tests/module_context/defs.h b/tests/module_context/defs.h
index b14ef45..1e485ec 100644
--- a/tests/module_context/defs.h
+++ b/tests/module_context/defs.h
@@ -13,10 +13,11 @@
 // The key the modules use to Get their name.
 constexpr char kLinkKey[] = "name";
 
-// The package name for the module under test.
-constexpr char kModulePackageName[] = "module_context_test_module";
+// The URL for the module under test.
+constexpr char kModuleUrl[] =
+    "fuchsia-pkg://fuchsia.com/module_context_test_module#meta/module_context_test_module.cmx";
 
 // The intent action |kModulePackageName| accepts.
 constexpr char kIntentAction[] = "action";
 
 // The names of the first and second modules to be stopped.
@@ -13,10 +13,11 @@
 
-// The intent action |kModulePackageName| accepts.
+// The intent action |kModuleUrl| accepts.
 constexpr char kIntentAction[] = "action";
 